@@ -26,6 +26,11 @@ test_that("get_time_bp_steps for standard dataset", {
     c(-20000, -15000, -10000, -5000, 0),
     ignore_attr = TRUE
   )
+  # expect error for dataset not downloaded yet
+  expect_error(
+    get_time_bp_steps(dataset = "WorldClim_2.1_MRI-ESM2-0_ssp370_5m"),
+    "no variable has been downloaded"
+  )
 })
 
 test_that("get_time_bp_steps for local file", {
@@ -41,14 +46,6 @@ test_that("get_time_bp_steps for local file", {
     c(-20000, -15000, -10000, -5000, 0),
     ignore_attr = TRUE
   )
-  expect_equal(
-    get_mis_time_steps(
-      mis = "2", dataset = "custom",
-      path_to_nc = path_to_example_nc
-    ),
-    c(-20000, -15000),
-    ignore_attr = TRUE
-  )
 })
 
 
